@@ -12,13 +12,6 @@ class weight_tab(TabBase):
     def initialize(self, Network_UI):
         self.weight_tab = Network_UI.Next_Tab(self.title)
 
-        Network_UI.Add_element(QLabel('Min Max'), stretch=0)
-        self.select_min_max_box = QComboBox()
-        self.select_min_max_box.addItems(['Transmitter', 'Global', 'Variable', 'Single block'])
-        self.select_min_max_box.setCurrentIndex(0)
-        Network_UI.Add_element(self.select_min_max_box, stretch=4)
-        Network_UI.Next_H_Block(stretch=0)
-
         #get max synapse group size
         max_sgs=2
         for group_tag in Network_UI.group_tags:
@@ -37,6 +30,13 @@ class weight_tab(TabBase):
                 self.transmitter_weight_images[transmitter].append(image_item)
             Network_UI.Next_H_Block()
 
+        Network_UI.Add_element(QLabel('Min Max'), stretch=0)
+        self.select_min_max_box = QComboBox()
+        self.select_min_max_box.addItems(['Transmitter', 'Global', 'Variable', 'Single block'])
+        self.select_min_max_box.setCurrentIndex(0)
+        Network_UI.Add_element(self.select_min_max_box, stretch=1)
+        #Network_UI.Next_H_Block(stretch=0)
+
     def update(self, Network_UI):
         if self.weight_tab.isVisible() and len(Network_UI.network[Network_UI.neuron_select_group]) > 0:
 
